pub struct CommandProcessedMessage {
pub command: String,
pub executor: Entity,
pub modifiers: HashMap<ModifierValue, ModifierValue>,
pub node: NodeIndex,
}Expand description
This will only be sent if the command was successfully parsed and an executable was found
Fields
command: Stringthe command that was executed eg. “teleport @p 0 ~ 0”
executor: Entityusually the Client entity but it could be a command block or something (whatever the library user wants)
modifiers: HashMap<ModifierValue, ModifierValue>the modifiers that were applied to the command
node: NodeIndexthe node that was executed